@@ -49,6 +49,7 @@ class ProcessServiceClient(object):
         raise Exception('Failed to connect to the process proxy')
 
     def execute_process(self, biomaj_process):
+        self.biomaj_process = biomaj_process
         if self.remote:
             self.channel.basic_publish(
                 exchange='',
@@ -58,14 +59,12 @@ class ProcessServiceClient(object):
                     # make message persistent
                     delivery_mode=2
                 ))
-        else:
-            self.biomaj_process = biomaj_process
 
     def wait_for_process(self):
         over = False
         exitcode = -1
         info = None
-        logging.info("Process:RemoteProcess:Waiting")
+        logging.info("Process:RemoteProcess:Waiting:" + str(self.biomaj_process.process.name))
         errors = 0
         while not over:
             if errors >= 3:
@@ -89,7 +88,7 @@ class ProcessServiceClient(object):
                 over = True
                 if result['exitcode'] > 0:
                     info = result['info']
-                    self.logger.error('Process:RemoteProcess:Error:' + str(result['info']))
+                    self.logger.error('Process:RemoteProcess:Error:' + str(self.biomaj_process.process.name) + ': ' + str(result['info']))
             else:
                 time.sleep(10)
         return (exitcode, info)
